==> nifi-1.20.0-source-release.zip: nifi-1.20.0/nifi-nar-bundles/nifi-aws-bundle/nifi-aws-processors/src/test/java/org/apache/nifi/processors/aws/cloudwatch/MockPutCloudWatchMetric.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.nifi.processors.aws.cloudwatch;

import com.amazonaws.AmazonClientException;
import com.amazonaws.services.cloudwatch.model.MetricDatum;
import com.amazonaws.services.cloudwatch.model.PutMetricDataRequest;
import com.amazonaws.services.cloudwatch.model.PutMetricDataResult;

import java.util.List;


/**
 * Simple mock {@link PutCloudWatchMetric} processor for testing.
 */
public class MockPutCloudWatchMetric extends PutCloudWatchMetric {

    protected String actualNamespace;
    protected List<MetricDatum> actualMetricData;
    protected AmazonClientException throwException;
    protected PutMetricDataResult result = new PutMetricDataResult();
    protected int putMetricDataCallCount = 0;

    protected PutMetricDataResult putMetricData(PutMetricDataRequest metricDataRequest) throws AmazonClientException {
        putMetricDataCallCount++;
        actualNamespace = metricDataRequest.getNamespace();
        actualMetricData = metricDataRequest.getMetricData();

        if (throwException != null) {
            throw throwException;
        }

        return result;
    }
}

==> nifi-1.28.1-source-release.zip: nifi-1.28.1/nifi-nar-bundles/nifi-aws-bundle/nifi-aws-processors/src/test/java/org/apache/nifi/processors/aws/cloudwatch/MockPutCloudWatchMetric.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.nifi.processors.aws.cloudwatch;

import com.amazonaws.AmazonClientException;
import com.amazonaws.services.cloudwatch.model.MetricDatum;
import com.amazonaws.services.cloudwatch.model.PutMetricDataRequest;
import com.amazonaws.services.cloudwatch.model.PutMetricDataResult;

import java.util.List;
import org.apache.nifi.processor.ProcessContext;


/**
 * Simple mock {@link PutCloudWatchMetric} processor for testing.
 */
public class MockPutCloudWatchMetric extends PutCloudWatchMetric {

    protected String actualNamespace;
    protected List<MetricDatum> actualMetricData;
    protected AmazonClientException throwException;
    protected PutMetricDataResult result = new PutMetricDataResult();
    protected int putMetricDataCallCount = 0;


    protected PutMetricDataResult putMetricData(ProcessContext context, PutMetricDataRequest metricDataRequest) throws AmazonClientException {
        putMetricDataCallCount++;
        actualNamespace = metricDataRequest.getNamespace();
        actualMetricData = metricDataRequest.getMetricData();

        if (throwException != null) {
            throw throwException;
        }

        return result;
    }
}
